@@ -14,7 +14,6 @@
 /* stuff for transforming a dictionary entry into a disjunct list */
 
 #include <math.h>
-#include "api-structures.h"
 #include "build-disjuncts.h"
 #include "dict-api.h"
 #include "dict-common.h"
@@ -459,7 +458,7 @@ X_node * build_word_expressions(Sentence sent, const Gword *w, const char *s)
 		y = (X_node *) xalloc(sizeof(X_node));
 		y->next = x;
 		x = y;
-		x->exp = copy_Exp(add_empty_word(dict, &eli, dn));
+		x->exp = copy_Exp(dn->exp);
 		if (NULL == s)
 		{
 			x->string = dn->string;
