@@ -11,13 +11,10 @@
 /*                                                                       */
 /*************************************************************************/
 
-#include <limits.h>
 #include <string.h>
 
 #include "build-disjuncts.h"
-#include "dict-api.h"
 #include "dict-common.h"
-#include "disjunct-utils.h"
 #include "error.h"
 #include "print.h"
 #include "externs.h"
@@ -25,10 +22,8 @@
 #include "read-dict.h"
 #include "regex-morph.h"
 #include "string-set.h"
-#include "tokenize.h"
 #include "utilities.h"
 #include "word-file.h"
-#include "utilities.h"
 
 const char * linkgrammar_get_version(void)
 {
@@ -994,70 +989,75 @@ static Exp * make_connector(Dictionary dict)
  * but can also be split into эт.= =о.mnsi. The problem arises because это.msi
  * is a single word, while эт.= =о.mnsi counts as two words, and there is no
  * pretty way to handle both during parsing. Thus a work-around is introduced:
- * add the empty word =.zzz: ZZZ+; to the dictionary.  This becomes a
- * pseudo-suffix that can attach to any plain word.  It can attach to any
- * plain word only because the routine below, add_empty_word(), adds the
- * corresponding connector ZZZ- to the plain word.  This is done "on the fly",
- * because we don't want to pollute the dictionary with this stuff.  Besides,
- * the Russian dictionary has more then 23K words that qualify for this
- * treatment (It has 22.5K words that appear both as plain words, and as
- * stems, and can thus attach to null suffixes. For non-null suffix splits,
- * there are clearly many more.)
+ * add the empty word EMPTY-WORD.zzz: ZZZ+; to the dictionary.  This becomes
+ * a pseudo-suffix that can attach to the previous word. It can attach to
+ * the previous word only because the routine below, add_empty_word(), adds
+ * the corresponding connector ZZZ- to the word.  This is done "on the
+ * fly", because we don't want to pollute the dictionary with this stuff.
+ * Besides, the Russian dictionary has more then 23K words that qualify for
+ * this treatment (It has 22.5K words that appear both as plain words, and
+ * as stems, and can thus attach to null suffixes. For non-null suffix
+ * splits, there are clearly many more.)
  *
  * The empty words are removed from the linkages after the parsing step.
  * FIXME However, the ZZZ connectors are still found in the chosen disjuncts
  * and can be visible in the API.
  */
-
-Exp* add_empty_word(Dictionary const dict, Exp_list * eli, Dict_node * dn)
+void add_empty_word(Dictionary const dict, X_node *x)
 {
-	size_t len;
 	Exp *zn, *an;
 	E_list *elist, *flist;
-	/* We assume the affix file has been read by now, so INFIX_MARK is set */
-	char infix_mark = INFIX_MARK(dict->affix_table);
+	Exp_list eli = { NULL };
 
-	if (! dict->empty_word_defined) return dn->exp;
+	/* The left-wall already has ZZZ-. The right-wall will not arrive here. */
+	if (MT_WALL == x->word->morpheme_type) return;
 
-	if (is_stem(dn->string)) return dn->exp;
-	len = strlen(dn->string);
-	if ((len > 1) && (infix_mark == dn->string[0])) return dn->exp;
-	if ((len > 1) && (infix_mark == dn->string[len-1])) return dn->exp;
-	if (0 == strcmp(dn->string, LEFT_WALL_WORD)) return dn->exp;
-	if (0 == strcmp(dn->string, RIGHT_WALL_WORD)) return dn->exp;
-	//lgdebug(+0, "Processing '%s'\n", dn->string);
+	/* Replace plain-word-exp by {ZZZ+} & (plain-word-exp) in each X_node.  */
+	for(; NULL != x; x = x->next)
+	{
+		/* Ignore stems for now, decreases a little the overhead for
+		 * stem-suffix languages.
+		 * This line should be removed if these 2 conditions happen together:
+		 * 1. Multi-stem splits are to be supported.
+		 * 2. Affix splits are done by wordgraph splits.
+		 *
+		 * FIXME: A more general solution instead of this line is to add
+		 * empty-word connectors only to the x-nodes that need them, instead
+		 * of adding them, like now, to all the x-nodes of the word that come
+		 * before the empty-word. This will support wordgraph affix splits (if
+		 * will ever be done) and will slightly increase the efficiency of
+		 * handling sentences with multi-suffix splits (less empty-word
+		 * connectors in the sentence). */
+		if (is_stem(x->string)) continue; /* Avoid an unneeded overhead. */
+		//lgdebug(+0, "Processing '%s'\n", x->string);
 
-	/* If we are here, then this appears to be not a stem, not a
-	 * suffix, and not an idiom word.
-	 * Create {ZZZ+} & (plain-word-exp). */
+		/* zn points at {ZZZ+} */
+		zn = Exp_create(&eli);
+		zn->dir = '+';
+		zn->u.string = string_set_add(EMPTY_CONNECTOR, dict->string_set);
+		zn->multi = false;
+		zn->type = CONNECTOR_type;
+		zn->cost = 0.0;
+		zn = make_optional_node(&eli, zn);
 
-	/* zn points at {ZZZ+} */
-	zn = Exp_create(eli);
-	zn->dir = '+';
-	zn->u.string = string_set_add(EMPTY_CONNECTOR, dict->string_set);
-	zn->multi = false;
-	zn->type = CONNECTOR_type;
-	zn->cost = 0.0;
-	zn = make_optional_node(eli, zn);
+		/* flist is plain-word-exp */
+		flist = (E_list *) xalloc(sizeof(E_list));
+		flist->next = NULL;
+		flist->e = x->exp;
 
-	/* flist is plain-word-exp */
-	flist = (E_list *) xalloc(sizeof(E_list));
-	flist->next = NULL;
-	flist->e = dn->exp;
+		/* elist is {ZZZ+} , (plain-word-exp) */
+		elist = (E_list *) xalloc(sizeof(E_list));
+		elist->next = flist;
+		elist->e = zn;
 
-	/* elist is {ZZZ+} , (plain-word-exp) */
-	elist = (E_list *) xalloc(sizeof(E_list));
-	elist->next = flist;
-	elist->e = zn;
+		/* an will be {ZZZ+} & (plain-word-exp) */
+		an = Exp_create(&eli);
+		an->type = AND_type;
+		an->cost = 0.0;
+		an->u.l = elist;
 
-	/* an will be {ZZZ+} & (plain-word-exp) */
-	an = Exp_create(eli);
-	an->type = AND_type;
-	an->cost = 0.0;
-	an->u.l = elist;
-
-	/* Return {ZZZ+} & (plain-word-exp) */
-	return an;
+		x->exp = an;
+	}
 }
 
 /* ======================================================================== */
