@@ -201,6 +201,10 @@ int strncasecmp(const char *s1, const char *s2, size_t n);
 #define MAX(X,Y)  ( ((X) > (Y)) ? (X) : (Y))
 #endif
 
+#if !defined(ARRAY_SIZE)
+#define ARRAY_SIZE(a) (sizeof(a) / sizeof((a)[0]))
+#endif
+
 /* Optimizations etc. that only gcc understands */
 #if __GNUC__ > 2
 #define GNUC_MALLOC __attribute__ ((malloc))
@@ -231,6 +235,18 @@ static inline size_t utf8_strlen(const char *s)
  */
 static inline size_t utf8_next(const char *s)
 {
+#ifdef _MSC_VER
+	/* mbrlen does not work correctly on Windows. See issue #285 */
+	/* https://github.com/opencog/link-grammar/issues/285 */
+	size_t len = 0;
+	while (0 != *s)
+	{
+		if ((0x80 <= ((unsigned char) *s)) &&
+		(((unsigned char) *s) < 0xc0)) { s++; len++; }
+		else return len+1;
+	}
+	return len;
+#else
 	size_t len;
 	mbstate_t mbs;
 	memset(&mbs, 0, sizeof(mbs));
@@ -239,8 +255,8 @@ static inline size_t utf8_next(const char *s)
 		/* Too long or malformed sequence, step one byte. */
 		return 1;
 	}
-
 	return len;
+#endif
 }
 
 static inline int is_utf8_upper(const char *s)
